@@ -10,6 +10,7 @@ from enum import Enum
 
 
 class MatcherType(Enum):
+    NOTHING = 'Nothing'
     ANYTHING = 'Anything'
     EQUAL_TO = 'EqualTo'
     STARTS_WITH = 'StartsWith'
@@ -22,7 +23,7 @@ def pull_val(x):
 class Matcher(ABC):
 
     def __init__(self, match_col_key):
-        self.matcher_type = None
+        self.matcher_type = MatcherType.NOTHING
         self.match_col_key = match_col_key
         self.my_logger = logging.getLogger('matching')
 
@@ -32,15 +33,15 @@ class Matcher(ABC):
 
     def get_key_val(self):
         """ Generate a value suitable for hashing, dictionary key"""
-        return frozenset((self.matcher_type.value, self.match_col_key.value))
+        return frozenset((self.matcher_type.value, self.match_col_key))
 
     def __repr__(self):
         return (f'{self.__class__.__name__}('
                 f'{self.matcher_type!r}, {self.match_col_key!r})')
 
     def __str__(self):
-        return (f'Matcher for {self.matcher_type.value!r} "'
-                f'"matching of {self.match_col_key.value!r}')
+        return (f'Matcher for {self.matcher_type.value!r} '
+                f'matching on field {self.match_col_key!r}')
 
     def __eq__(self, other):
         if other.__class__ is self.__class__:
@@ -53,6 +54,18 @@ class Matcher(ABC):
         return hash((self.__class__, self.matcher_type, self.match_col_key))
 
 
+class NothingMatcher(Matcher):
+
+    def __init__(self, match_col_key):
+        super().__init__(match_col_key)
+        self.match_col_key = match_col_key
+        self.matcher_type = MatcherType.NOTHING
+
+    def is_match(self, match_values, data_record) -> bool:
+        self.my_logger.info("No Matcher set, defaults to Nothing Matcher. Always False.")
+        return False
+
+
 class AnythingMatcher(Matcher):
 
     def __init__(self, match_col_key):
@@ -65,6 +78,9 @@ class AnythingMatcher(Matcher):
         return match_equality(self.my_matcher) == data_record
 
 
+
+
+
 class EqualTo(Matcher):
     """ Equal To matching style. Cast everything to str. """
 
